# -*- coding: utf-8 -*-

import unittest, ephem

tle_lines = (
    'ISS (ZARYA)             ',
    '1 25544U 98067A   09119.77864163  .00009789  00000-0  76089-4 0  7650',
    '2 25544  51.6397 195.1243 0008906 304.8273 151.9344 15.72498628598335',
    )

class SatelliteTests(unittest.TestCase):
    def setUp(self):
        self.iss = ephem.readtle(*tle_lines)
        self.atlanta = ephem.city('Atlanta')

    def test_normal_methods(self):
        for which in ['previous', 'next']:
            for event in ['transit', 'antitransit', 'rising', 'setting']:
                method_name = which + '_' + event
                method = getattr(self.atlanta, method_name)
                self.assertRaises(TypeError, method, self.iss)

    def test_next_pass(self):
        iss = self.iss
        self.atlanta.date = '2009/4/30'
        rt, raz, tt, talt, st, saz = self.atlanta.next_pass(iss)

        # Calsky says (using EST, and probably a different horizon):
        #  Rise(invis.)  1h02m17s  --.-mag  az:192.0° SSW
        #  Culmination   1h06m39s  --.-mag  az:128.2° SE   h:16.0°
        #  Set (invis.)  1h11m04s  --.-m  az: 64.9° ENE

        self.assertAlmostEqual(ephem.Date('2009/4/30 5:02:17'), rt, 3)
        self.assertAlmostEqual(ephem.Date('2009/4/30 5:06:39'), tt, 3)
        self.assertAlmostEqual(ephem.Date('2009/4/30 5:11:04'), st, 3)

        self.assertAlmostEqual(ephem.degrees('192.0'), raz, 1)
        self.assertAlmostEqual(ephem.degrees('16.0'), talt, 1)
        self.assertAlmostEqual(ephem.degrees('64.9'), saz, 1)

    def test_more_than_one_year_before_TLE(self):
        self.assertRaises(ValueError, self.iss.compute, '2008/4/28')

    def test_more_than_one_year_after_TLE(self):
        self.assertRaises(ValueError, self.iss.compute, '2010/4/30 20:00')



#!/usr/bin/env python

import ephem
import locale
import sys

if sys.version_info < (2, 7):
    import unittest2 as unittest
else:
    import unittest

# Determine whether we can convert values regardless of locale.

class locales_suite(unittest.TestCase):
    def setUp(self):
        self.old_locale = locale.getlocale(locale.LC_NUMERIC)
        try:
            locale.setlocale(locale.LC_NUMERIC, 'de_CH.UTF-8')
        except locale.Error:
            self.locale_available = False
        else:
            self.locale_available = True

    def tearDown(self):
        locale.setlocale(locale.LC_NUMERIC, self.old_locale)

    def test_date_creation(self):
        if not self.locale_available:
            raise unittest.SkipTest()
        self.assertEqual(ephem.date('2008.5'), 39629.5) # instead of 2008.0

    def test_satellite_creation(self):
        if not self.locale_available:
            raise unittest.SkipTest()
        s = ephem.readtle('ISS (ZARYA)',
                          '1 25544U 98067A   08334.54218750  .00025860  '
                          '00000-0  20055-3 0  7556',
                          '2 25544 051.6425 248.8374 0006898 046.3246 '
                          '303.9711 15.71618375574540594')
        self.assertEqual(str(s._raan), '248:50:14.6') # instead of :00:00.0



#!/usr/bin/env python

import doctest
import unittest
import os.path
import sys
import time
from glob import glob

def load_tests(loader, tests, pattern):

    # Force time zone to EST/EDT to make localtime tests work.
    os.environ['TZ'] = 'EST+05EDT,M4.1.0,M10.5.0'
    time.tzset()

    # The different floating-point formatting rules in 2.6 and prior
    # ruin our doctests.

    tests = []

    if sys.version_info >= (2, 7):
        tests.extend([
            doctest.DocFileSuite('../doc/%s' % os.path.basename(path))
            for path in glob(os.path.dirname(__file__) + '/../doc/*.rst')
            if os.path.split(path)[-1] != 'index.rst'
            # skips time-dependent doctest in index.rst
            ])

    return unittest.TestSuite(tests)
